<?php

/*
 * This file is part of the Comptoir-du-Libre software.
 * <https://gitlab.adullact.net/Comptoir/comptoir-du-libre>
 *
 * Copyright (c) ADULLACT   <https://adullact.org>
 *               Association des Développeurs et Utilisateurs de Logiciels Libres
 *               pour les Administrations et les Collectivités Territoriales
 *
 * Comptoir-du-Libre is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this software. If not, see <https://www.gnu.org/licenses/agpl-3.0.en.html>.
 */

declare(strict_types=1);

namespace App\Controller\Organization;

use App\Entity\Organization;
use App\Entity\OrganizationI18n;
use App\Entity\OrganizationType;
use App\Form\Organization\OrganizationFormType;
use App\Repository\OrganizationI18nRepository;
use App\Repository\OrganizationRepository;
use App\Repository\OrganizationTypeRepository;
use Symfony\Bridge\Twig\Attribute\Template;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Form\FormFactoryInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;
use Symfony\Component\String\Slugger\AsciiSlugger;
use Symfony\Contracts\Translation\TranslatorInterface;

use function Symfony\Component\String\u;

#[Route(
    requirements: [
        '_locale' => 'en|fr',
    ],
)]
class OrganizationManageController extends AbstractController
{
    #[Route(
        path: [
            'en' => '/{_locale}/organizations/new',
            'fr' => '/{_locale}/organisations/new',
        ],
        name: 'app_connected_user_add_organization',
        methods: ['GET', 'POST']
    )]
    public function createNewOrganization(
        string $_locale,
        Request $request,
        FormFactoryInterface $formFactory,
        TranslatorInterface $translator,
        OrganizationRepository $organizationRepository,
        OrganizationI18nRepository $organizationI18nRepository,
    ): Response {
        $sessionFormToken = '11111';
        $form = $formFactory->createNamed(
            name: "new_organization_$sessionFormToken",
            type: OrganizationFormType::class,
            data: new Organization(),
        );
        $form->handleRequest($request);


        if ($form->isSubmitted() && $form->isValid()) {
            $orgType = $form->get('type')->getData();
            $orgName = $form->get('name')->getData();
            $orgWebsite = $form->get('website')->getData();

            $slugger = new AsciiSlugger();
            $slug = u($slugger->slug("$orgName")->toString())->lower()->toString();

            // Add new user
            $now = new \DateTimeImmutable();
            $organization = new Organization();
            $organization->setUpdatedAt($now);
            $organization->setCreatedAt($now);
            $organization->setType($orgType);
            $organization->setName($orgName);
            $organization->setWebsite($orgWebsite);
            $organization->setSlug($slug);
            $organizationRepository->save($organization, true);

            if (!empty($form->get('description')->getData())) {
                $organizationI18n = new OrganizationI18n();
                $organizationI18n->setOrganization($organization);
                $organizationI18n->setLocale($_locale);
                $organizationI18n->setType(1);
                $organizationI18n->setText($form->get('description')->getData());
                $organizationI18nRepository->save($organizationI18n, true);
            }

            $this->addFlash(
                'success',
                $translator->trans('organization.update_form.success', ['organization_name' => $orgName]),
            );
            return $this->redirectToRoute('app_anonymous_organization_display_one_organization', [
                '_locale' => $_locale,
                'id' => $organization->getId(),
                'slug' => $organization->getSlug(),
            ]);

            // https://symfony.com/doc/current/reference/forms/types/file.html#mapped
            // https://symfony.com/doc/6.4/controller/upload_file.html
        }

        // Display form (first display or user errors in form)
        return $this->render(
            view: 'webapp/organization/form_create_organization.html.twig',
            parameters: [
                'organizationForm' => $form->createView(),
            ]
        );
    }


    #[Route(
        path: [
            'en' => '/{_locale}/organization/{id}/{slug}/edit',
            'fr' => '/{_locale}/organisation/{id}/{slug}/edit',
        ],
        name: 'app_connected_user_update_organization',
        methods: ['GET', 'POST']
    )]
    public function updateOrganization(
        string $_locale,
        Organization $organization,
        OrganizationRepository $organizationRepository,
        OrganizationI18nRepository $organizationI18nRepository,
        Request $request,
        TranslatorInterface $translator,
    ): Response|RedirectResponse {

        $organizationI18n = $organizationI18nRepository->findOneBy([
            'organization' => $organization->getId(),
            'locale' => $_locale,
            'type' => 1
        ]); // @@@TODO improve it: if empty --> get other local
        // $organization->getOrganizationI18ns();

        $organizationDescription = '';
        if (is_object($organizationI18n)) {
            $organizationDescription = $organizationI18n->getText();
        } else {
            $organizationI18n = new OrganizationI18n();
            $organizationI18n->setOrganization($organization);
            $organizationI18n->setLocale($_locale);
            $organizationI18n->setType(1);
        }

        $form = $this->createForm(
            type: OrganizationFormType::class,
            data: $organization,
            options: ['organization_description' => $organizationDescription]
        );
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $orgType = $form->get('type')->getData();
            $orgName = $form->get('name')->getData();
            $orgWebsite = $form->get('website')->getData();

            $slugger = new AsciiSlugger();
            $slug = u($slugger->slug("$orgName")->toString())->lower()->toString();

            if (!empty($form->get('description')->getData())) {
                $organizationI18n->setText($form->get('description')->getData());
                $organizationI18nRepository->save($organizationI18n, true);
            }
            $now = new \DateTimeImmutable();
            $organization->setUpdatedAt($now);
            $organization->setType($orgType);
         // $organization->setName($orgName);
         // $organization->setWebsite($orgWebsite);
            $organization->setSlug($slug);
         // $organization->addOrganizationI18n($organizationDescription);
            $organizationRepository->save($organization, true);

            // Redirect user and display success message
            $this->addFlash(
                'success',
                $translator->trans('organization.update_form.success', ['organization_name' => $orgName]),
            );
            return $this->redirectToRoute('app_anonymous_organization_display_one_organization', [
                '_locale' => $_locale,
                'id' => $organization->getId(),
                'slug' => $organization->getSlug(),
            ]);

            // https://symfony.com/doc/current/reference/forms/types/file.html#mapped
            // https://symfony.com/doc/6.4/controller/upload_file.html
        }


        // Display form (first display or user errors in form)
        return $this->render(
            view: 'webapp/organization/form_update_organization.html.twig',
            parameters: [
               'organizationForm' => $form->createView(),
                '_locale' => $_locale,
                'organization' => $organization,
                'organization_type' => $organization->getType()->getName(),
            ],
        );
    }
}
