<?php

/*
 * This file is part of the Comptoir-du-Libre software.
 * <https://gitlab.adullact.net/Comptoir/comptoir-du-libre>
 *
 * Copyright (c) ADULLACT   <https://adullact.org>
 *               Association des Développeurs et Utilisateurs de Logiciels Libres
 *               pour les Administrations et les Collectivités Territoriales
 *
 * Comptoir-du-Libre is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public Organization as published
 * by the Free Software Foundation, either version 3 of the Organization, or
 * (at your option) any later version.
 *
 * You should have received a copy of the GNU Affero General Public Organization
 * along with this software. If not, see <https://www.gnu.org/licenses/agpl-3.0.en.html>.
 */

declare(strict_types=1);

namespace App\Tests\Functional\Organization;

use App\DataFixtures\AppOrganizationFixtures;
use App\Tests\Functional\TestHelperBreadcrumbTrait;
use App\Tests\Functional\TestHelperTrait;
use Symfony\Bundle\FrameworkBundle\KernelBrowser;
use Symfony\Bundle\FrameworkBundle\Test\WebTestCase;
use Symfony\Component\HttpFoundation\Response;

/**
 * @group allow_mutation_testing_by_infection
 * @group gogogo
 */
class FunctionalTestOrganizationPagesTest extends WebTestCase
{
    use TestHelperTrait;
    use TestHelperBreadcrumbTrait;

    ///////////////////////////////////////////////////////////////////////////////////

    public function testAllOrganizationsPageAllowToChangeLocaleInUrl(): void
    {
        $client = static::createClient();
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/en/organisations/",
            expectedNewUrl: "/en/organizations/",
            expectedCurrentRoute: 'app_anonymous_organization_display_all_allow_to_change_locale_in_url',
            expectedNewRoute: 'app_anonymous_organization_display_all_organization',
        );
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/fr/organizations/",
            expectedNewUrl: "/fr/organisations/",
            expectedCurrentRoute: 'app_anonymous_organization_display_all_allow_to_change_locale_in_url',
            expectedNewRoute: 'app_anonymous_organization_display_all_organization',
        );
    }

    ///////////////////////////////////////////////////////////////////////////////////

    public function testAllPublicSectorOrganizationsPageAllowToChangeLocaleInUrl(): void
    {
        $client = static::createClient();
        $type = "public_sector";
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/en/organisations/administration/",
            expectedNewUrl: "/en/organizations/public-sector/",
            expectedCurrentRoute: "app_anonymous_organization_display_all_${type}_allow_to_change_locale_in_url",
            expectedNewRoute: "app_anonymous_organization_display_all_org_$type",
        );
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/fr/organizations/public-sector/",
            expectedNewUrl: "/fr/organisations/administration/",
            expectedCurrentRoute: "app_anonymous_organization_display_all_${type}_allow_to_change_locale_in_url",
            expectedNewRoute: "app_anonymous_organization_display_all_org_$type",
        );
    }

    public function testAllNoProfitOrganizationsPageAllowToChangeLocaleInUrl(): void
    {
        $client = static::createClient();
        $type = "no_profit";
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/en/organisations/association/",
            expectedNewUrl: "/en/organizations/non-profit/",
            expectedCurrentRoute: "app_anonymous_organization_display_all_${type}_allow_to_change_locale_in_url",
            expectedNewRoute: "app_anonymous_organization_display_all_org_$type",
        );
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/fr/organizations/non-profit/",
            expectedNewUrl: "/fr/organisations/association/",
            expectedCurrentRoute: "app_anonymous_organization_display_all_${type}_allow_to_change_locale_in_url",
            expectedNewRoute: "app_anonymous_organization_display_all_org_$type",
        );
    }

    public function testAllCompaniesPageAllowToChangeLocaleInUrl(): void
    {
        $client = static::createClient();
        $type = "company";
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/en/organisations/entreprises/",
            expectedNewUrl: "/en/organizations/companies/",
            expectedCurrentRoute: "app_anonymous_organization_display_all_${type}_allow_to_change_locale_in_url",
            expectedNewRoute: "app_anonymous_organization_display_all_org_$type",
        );
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/fr/organizations/companies/",
            expectedNewUrl: "/fr/organisations/entreprises/",
            expectedCurrentRoute: "app_anonymous_organization_display_all_${type}_allow_to_change_locale_in_url",
            expectedNewRoute: "app_anonymous_organization_display_all_org_$type",
        );
    }

    ///////////////////////////////////////////////////////////////////////////////////

    public function testOneOrganizationPageAllowToTruncateUrlToRedirectToAllOrganizationsPage(): void
    {
        $client = static::createClient();
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/en/organization/",
            expectedNewUrl: "/en/organizations/",
            expectedCurrentRoute: 'app_anonymous_organization_display_all_fix_url_typo',
            expectedNewRoute: 'app_anonymous_organization_display_all_organization',
        );
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/fr/organisation/",
            expectedNewUrl: "/fr/organisations/",
            expectedCurrentRoute: 'app_anonymous_organization_display_all_fix_url_typo',
            expectedNewRoute: 'app_anonymous_organization_display_all_organization',
        );
    }

    public function testOneOrganizationPageAllowToChangeLocaleInUrl(): void
    {
        $organizationId = AppOrganizationFixtures::ORGANIZATIONS[3]['id'];
        $organizationSlug = AppOrganizationFixtures::ORGANIZATIONS[$organizationId]['slug'];
        $client = static::createClient();
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/en/organisation/$organizationId/$organizationSlug/",
            expectedNewUrl: "/en/organization/$organizationId/$organizationSlug/",
            expectedCurrentRoute: 'app_anonymous_organization_display_one_allow_to_change_locale_in_url',
            expectedNewRoute: 'app_anonymous_organization_display_one_organization',
        );
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/fr/organization/$organizationId/$organizationSlug/",
            expectedNewUrl: "/fr/organisation/$organizationId/$organizationSlug/",
            expectedCurrentRoute: 'app_anonymous_organization_display_one_allow_to_change_locale_in_url',
            expectedNewRoute: 'app_anonymous_organization_display_one_organization',
        );
    }

    public function testOneOrganizationPageWithoutSlugRedirectToValidUrl(): void
    {
        $organizationId = AppOrganizationFixtures::ORGANIZATIONS[3]['id'];
        $organizationSlug = AppOrganizationFixtures::ORGANIZATIONS[$organizationId]['slug'];
        $client = static::createClient();
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/en/organization/$organizationId/",
            expectedNewUrl: "/en/organization/$organizationId/$organizationSlug/",
            expectedCurrentRoute: 'app_anonymous_organization_display_one_organization_without_slug',
            expectedNewRoute: 'app_anonymous_organization_display_one_organization',
        );
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/fr/organisation/$organizationId/",
            expectedNewUrl: "/fr/organisation/$organizationId/$organizationSlug/",
            expectedCurrentRoute: 'app_anonymous_organization_display_one_organization_without_slug',
            expectedNewRoute: 'app_anonymous_organization_display_one_organization',
        );
    }

    public function testOneOrganizationPageWithBadSlugRedirectToValidUrl(): void
    {
        $organizationId = AppOrganizationFixtures::ORGANIZATIONS[3]['id'];
        $organizationSlug = AppOrganizationFixtures::ORGANIZATIONS[$organizationId]['slug'];
        $client = static::createClient();
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/en/organization/$organizationId/not-valid-slug/",
            expectedNewUrl: "/en/organization/$organizationId/$organizationSlug/",
            expectedCurrentRoute: 'app_anonymous_organization_display_one_organization',
            expectedNewRoute: 'app_anonymous_organization_display_one_organization',
        );
        $this->checkRedirectionToNewUrl(
            client: $client,
            currentUrl: "/fr/organisation/$organizationId/not-valid-slug/",
            expectedNewUrl: "/fr/organisation/$organizationId/$organizationSlug/",
            expectedCurrentRoute: 'app_anonymous_organization_display_one_organization',
            expectedNewRoute: 'app_anonymous_organization_display_one_organization',
        );
    }

    //////////////////////////////////////////////////////////////////////////////////////////////////////

    public function testAllOrganizationsPageDisplay(): void
    {
        $this->commonCheckerAllOrganizationsPageDisplay(
            locale: 'en',
            expectedTitle: 'Organizations: public sector, associations and companies - Comptoir du Libre TEST',
            expectedH1: 'Organizations',
        );
    }

    public function testAllOrganizationsPageDisplayForFrenchLocale(): void
    {
        $this->commonCheckerAllOrganizationsPageDisplay(
            locale: 'fr',
            expectedTitle: 'Organisations - Comptoir du Libre TEST',
            expectedH1: 'Organisations',
        );
    }

    private function commonCheckerAllOrganizationsPageDisplay(
        string $locale,
        string $expectedTitle,
        string $expectedH1,
    ): void {
        $i18nUrlOneOrganization = 'organization';
        $i18nUrlAllOrganizations = 'organizations';
        $i18nTextNumberOfOrganizations = 'organizations';
        if ($locale === 'fr') {
            $i18nUrlOneOrganization = 'organisation';
            $i18nUrlAllOrganizations = 'organisations';
            $i18nTextNumberOfOrganizations = 'organisations';
        }

        $i18nUrlAllOrganizations = "/$locale/$i18nUrlAllOrganizations/";
        $organizations = AppOrganizationFixtures::ORGANIZATIONS;

        // Basic checks
        $client = static::createClient();
        $crawler = $client->request('GET', "$i18nUrlAllOrganizations");
        $this->assertRouteSame('app_anonymous_organization_display_all_organization');
        $this->assertResponseStatusCodeSame(Response::HTTP_OK); // HTTP status code = 200
        $this->assertSelectorTextSame('h1', "$expectedH1");
        $this->assertPageTitleSame($expectedTitle);

        // HTML Breadcrumb
        $breadcrumbLinks = [
            "$i18nUrlAllOrganizations" => "$expectedH1",
        ];
        $this->checkHasValidBreadcrumb($crawler, $breadcrumbLinks, "$locale");

        // HTML - Organization list
        $this->assertSelectorCount(1, "ul.organization_collection");
        $numberOfOrganizations = \count($crawler->filter("ul.organization_collection li"));
        $this->assertGreaterThanOrEqual(count(AppOrganizationFixtures::ORGANIZATIONS), $numberOfOrganizations);
        $this->assertSelectorTextContains(
            '#organization_count',
            "$numberOfOrganizations $i18nTextNumberOfOrganizations", // example: "6 organizations"
        );
        foreach ($organizations as $key => $organization) {
            $organizationId =  AppOrganizationFixtures::ORGANIZATIONS[$key]['id'];
            $organizationSlug =  AppOrganizationFixtures::ORGANIZATIONS[$key]['slug'];

            // TODO Fixme
            $this->checkAttribute(
                crawler: $crawler,
                cssFilter: "ul.organization_collection li.organization_$organizationId a",
                attributesExpected: [
                    '_name' => 'a',
                    '_text' => AppOrganizationFixtures::ORGANIZATIONS[$key]['name'],
                    'href'  => "/$locale/$i18nUrlOneOrganization/$organizationId/$organizationSlug/"
                ]
            );
        }
    }

    /////////////////////////////////////////////////////////////////////////////////////////////////////


    public function testAllPublicSectorOrganizationsPageDisplay(): void
    {
        $this->commonCheckerAllOrganizationsByTypePageDisplay(
            locale: 'en',
            type: 'public_sector',
        );
    }
    public function testAllPublicSectorOrganizationsPageDisplayForFrenchLocale(): void
    {
        $this->commonCheckerAllOrganizationsByTypePageDisplay(
            locale: 'fr',
            type: 'public_sector',
        );
    }

    public function testAllNoProfitOrganizationsPageDisplay(): void
    {
        $this->commonCheckerAllOrganizationsByTypePageDisplay(
            locale: 'en',
            type: 'no_profit',
        );
    }
    public function testAllNoProfitOrganizationsPageDisplayForFrenchLocale(): void
    {
        $this->commonCheckerAllOrganizationsByTypePageDisplay(
            locale: 'fr',
            type: 'no_profit',
        );
    }

    public function testAllCompaniesOrganizationsPageDisplay(): void
    {
        $this->commonCheckerAllOrganizationsByTypePageDisplay(
            locale: 'en',
            type: 'company',
        );
    }
    public function testAllCompaniesOrganizationsPageDisplayForFrenchLocale(): void
    {
        $this->commonCheckerAllOrganizationsByTypePageDisplay(
            locale: 'fr',
            type: 'company',
        );
    }

    private function commonCheckerAllOrganizationsByTypePageDisplay(
        string $locale,
        string $type,
    ): void {
        $appName = 'Comptoir du Libre TEST';
        $i18nUrlOneOrganization = 'organization';
        $i18nUrlAllOrganizations = 'organizations';
        $i18nOrganisationTypes = [
            'public_sector' => [
                'inUrl' => 'public-sector',
                'title' => "Public sector: local authorities, administrations… - $appName",
                'h1' => 'Public sector',
                'countText' => 'local authorities, administrations and other public services',
                'breadcrumbAllOrganizations' => 'Organizations',
                'breadcrumbAllOrganizationsByType' => 'Public sector',
            ],
            'no_profit' => [
                'inUrl' => 'non-profit',
                'title' => "Associations - $appName",   // TODO i18n
                'h1' => 'Associations',                 // TODO i18n
                'countText' => 'associations',          // TODO i18n
                'breadcrumbAllOrganizations' => 'Organizations',
                'breadcrumbAllOrganizationsByType' => 'Associations',
            ],
            'company' => [
                'inUrl' => 'companies',
                'title' => "Companies - $appName",
                'h1' => 'Companies',
                'countText' => 'companies',
                'breadcrumbAllOrganizations' => 'Organizations',
                'breadcrumbAllOrganizationsByType' => 'Companies',
            ],
        ];
        if ($locale === 'fr') {
            $i18nUrlOneOrganization = 'organisation';
            $i18nUrlAllOrganizations = 'organisations';
            $i18nOrganisationTypes = [
                'public_sector' => [
                    'inUrl' => 'administration',
                    'title' => "Services Publics : collectivités territoriales, administrations… - $appName",
                    'h1' => 'Services Publics',
                    'countText' => 'collectivités territoriales, administrations et autres services publics',
                    'breadcrumbAllOrganizations' => 'Organisations',
                    'breadcrumbAllOrganizationsByType' => 'Services Publics',
                ],
                'no_profit' => [
                    'inUrl' => 'association',
                    'title' => "Associations - $appName",   // TODO i18n
                    'h1' => 'Associations',                 // TODO i18n
                    'countText' => 'associations',          // TODO i18n
                    'breadcrumbAllOrganizations' => 'Organisations',
                    'breadcrumbAllOrganizationsByType' => 'Associations',
                ],
                'company' => [
                    'inUrl' => 'entreprises',
                    'title' => "Entreprises - $appName",
                    'h1' => 'Entreprises',
                    'countText' => 'entreprises',
                    'breadcrumbAllOrganizations' => 'Organisations',
                    'breadcrumbAllOrganizationsByType' => 'Entreprises',
                ],
            ];
        }


        $expectedTitle = $i18nOrganisationTypes[$type]['title'];
        $expectedH1 =  $i18nOrganisationTypes[$type]['h1'];
        $i18nTextNumberOfOrganizations =  $i18nOrganisationTypes[$type]['countText'];
        $i18nUrlAllOrganizations = "/$locale/$i18nUrlAllOrganizations/";
        $i18nUrlAllOrganizationsByType = $i18nUrlAllOrganizations . $i18nOrganisationTypes[$type]['inUrl'] . '/';
        $organizations = AppOrganizationFixtures::ORGANIZATIONS;

        // Basic checks
        $client = static::createClient();
        $crawler = $client->request('GET', "$i18nUrlAllOrganizationsByType");
        $this->assertRouteSame("app_anonymous_organization_display_all_org_$type",);
        $this->assertResponseStatusCodeSame(Response::HTTP_OK); // HTTP status code = 200
        $this->assertSelectorTextSame('h1', "$expectedH1");
        $this->assertPageTitleSame($expectedTitle);

        // HTML Breadcrumb
        $breadcrumbLinks = [
            "$i18nUrlAllOrganizations" => $i18nOrganisationTypes[$type]['breadcrumbAllOrganizations'],
            "$i18nUrlAllOrganizationsByType" => $i18nOrganisationTypes[$type]['breadcrumbAllOrganizationsByType'],
        ];
        $this->checkHasValidBreadcrumb($crawler, $breadcrumbLinks, "$locale");

        // HTML - Organization list
        $this->assertSelectorCount(1, "ul.organization_collection");
        $numberOfOrganizations = \count($crawler->filter("ul.organization_collection li"));
        $this->assertSelectorTextContains(
            '#organization_count',
            "$numberOfOrganizations $i18nTextNumberOfOrganizations", // example: "6 organizations"
        );
        $expectedNumberOfOrganizations = 0;
        foreach ($organizations as $key => $organization) {
            $organizationId =  AppOrganizationFixtures::ORGANIZATIONS[$key]['id'];
            $organizationType =  AppOrganizationFixtures::ORGANIZATIONS[$key]['type'];
            $organizationSlug =  AppOrganizationFixtures::ORGANIZATIONS[$key]['slug'];
            if ($organizationType === $type) {
                $expectedNumberOfOrganizations++;

                // TODO fixme
                $this->checkAttribute(
                    crawler: $crawler,
                    cssFilter: "ul.organization_collection li.organization_$organizationId a",
                    attributesExpected: [
                        '_name' => 'a',
                        '_text' => AppOrganizationFixtures::ORGANIZATIONS[$key]['name'],
                        'href'  => "/$locale/$i18nUrlOneOrganization/$organizationId/$organizationSlug/"
                    ]
                );
            } else {
                $this->assertSelectorCount(
                    expectedCount: 0,
                    selector: "ul.organization_collection li.organization_$organizationId"
                );
            }
        }
        $this->assertGreaterThanOrEqual($expectedNumberOfOrganizations, $numberOfOrganizations);
    }

    /////////////////////////////////////////////////////////////////////////////////////////////////////:

    /**
     * @group gogogo3
     */
    public function testOneOrganizationPageDisplay(): void
    {
        $kernelBrowser = static::createClient();
        $this->commonCheckerOneOrganizationPageDisplay($kernelBrowser, 'en', 1);  // no profit
        $this->commonCheckerOneOrganizationPageDisplay($kernelBrowser, 'en', 6);  // public sector
        $this->commonCheckerOneOrganizationPageDisplay($kernelBrowser, 'en', 10); // private sector

        $this->markTestIncomplete();
            // HTML - Publishing informations
            // HTML - Organization WEBSITE
            // HTML - Organization DESCRIPTION
    }

    /**
     * @group gogogo3
     */
    public function testOneOrganizationPageDisplayForFrenchLocale(): void
    {
        $kernelBrowser = static::createClient();
        $this->commonCheckerOneOrganizationPageDisplay($kernelBrowser, 'fr', 1);  // no profit
        $this->commonCheckerOneOrganizationPageDisplay($kernelBrowser, 'fr', 6);  // public sector
        $this->commonCheckerOneOrganizationPageDisplay($kernelBrowser, 'fr', 10); // private sector

        $this->markTestIncomplete();
            // HTML - Publishing informations
            // HTML - Organization WEBSITE
            // HTML - Organization DESCRIPTION
    }

    private function commonCheckerOneOrganizationPageDisplay(
        KernelBrowser $kernelBrowser,
        string $locale,
        int $organizationKey,
    ): void {
        $i18nConfig = [
            'i18nUrlPrefix_organizationSingle' => 'organization',
            'i18nUrlPrefix_organizationPlural' => 'organizations',
            'public_sector' => [
                'i18nUrl_organizationPrefix' => 'public-sector',
                'i18nUrl_organizationType' => 'public-sector',
                'i18nBreadcrumb_organizationType' => 'Public sector',
            ],
            'no_profit' => [
                'i18nUrl_organizationType' => 'non-profit',          // TODO i18n fixme
                'i18nBreadcrumb_organizationType' => 'Associations', // TODO i18n fixme
            ],
            'company' => [
                'i18nUrl_organizationType' => 'companies',
                'i18nBreadcrumb_organizationType' => 'Companies',
            ],
        ];
        if ($locale === 'fr') {
            $i18nConfig = [
                'i18nUrlPrefix_organizationSingle' => 'organisation',
                'i18nUrlPrefix_organizationPlural' => 'organisations',
                'public_sector' => [
                    'i18nUrl_organizationType' => 'administration', // TODO i18n fixme
                    'i18nBreadcrumb_organizationType' => 'Services Publics',
                ],
                'no_profit' => [
                    'i18nUrl_organizationType' => 'association',          // TODO i18n fixme
                    'i18nBreadcrumb_organizationType' => 'Associations', // TODO i18n fixme
                ],
                'company' => [
                    'i18nUrl_organizationType' => 'entreprises',
                    'i18nBreadcrumb_organizationType' => 'Entreprises',
                ],
            ];
        }


        $organizationId = AppOrganizationFixtures::ORGANIZATIONS[$organizationKey]['id'];
        $organizationSlug = AppOrganizationFixtures::ORGANIZATIONS[$organizationId]['slug'];
        $organizationName = AppOrganizationFixtures::ORGANIZATIONS[$organizationId]['name'];
        $organizationType = AppOrganizationFixtures::ORGANIZATIONS[$organizationId]['type'];
        $organizationLogo = "";
        if (isset(AppOrganizationFixtures::ORGANIZATIONS[$organizationId]['logo'])) {
            $organizationLogo = AppOrganizationFixtures::ORGANIZATIONS[$organizationId]['logo'];
        }
        $organizationWebsite = "";
        if (isset(AppOrganizationFixtures::ORGANIZATIONS[$organizationId]['website'])) {
            $organizationWebsite = AppOrganizationFixtures::ORGANIZATIONS[$organizationId]['website'];
        }

        $urlOrganizationPrefixSingle = $i18nConfig['i18nUrlPrefix_organizationSingle'];
        $urlOrganizationPrefixPlural = $i18nConfig['i18nUrlPrefix_organizationPlural'];
        $organizationUrl = "/$locale/$urlOrganizationPrefixSingle/$organizationId/$organizationSlug/";

        // Basic cheks
        $crawler = $kernelBrowser->request('GET', "$organizationUrl");
        $this->assertRouteSame('app_anonymous_organization_display_one_organization');
        $this->assertResponseStatusCodeSame(Response::HTTP_OK); // HTTP status code = 200
        $this->assertSelectorTextSame('h1', "$organizationName");
        $this->assertPageTitleSame("$organizationName - Comptoir du Libre TEST");

        // HTML - Breadcrumb
        $urlOrganizationType = $i18nConfig["$organizationType"]['i18nUrl_organizationType'];
        $breadcrumbOrganizationType = $i18nConfig["$organizationType"]['i18nBreadcrumb_organizationType'];
        $breadcrumbLinks = [
            "/$locale/$urlOrganizationPrefixPlural/$urlOrganizationType/" => $breadcrumbOrganizationType,
            "$organizationUrl" => "$organizationName",
        ];
        $this->checkHasValidBreadcrumb($crawler, $breadcrumbLinks, "$locale");

        // HTML - Organization LOGO
        $this->assertSelectorCount(1, "img.qa_organization_logo");
        if ($organizationLogo === '') {
            $this->checkAttribute(
                crawler: $crawler,
                cssFilter: "img.qa_organization_logo_placeholder",
                attributesExpected: [
                    'class'  => "qa_organization_logo qa_organization_logo_placeholder",
                    'src' => "/images/placeholder_organization.png",
                    'loading'  => "lazy",
                    'alt'  => "",
                ]
            );
        } else {
            $this->assertSelectorCount(expectedCount: 0, selector: ".qa_organization_logo_placeholder");
            $this->checkAttribute(
                crawler: $crawler,
                cssFilter: "img.qa_organization_logo",
                attributesExpected: [
                    'src' => "/images/content/organization/$organizationId/logo/$organizationLogo",
                    'loading'  => "lazy",
                    'alt'  => "$organizationName",
                ]
            );
        }
        // HTML - Publishing informations
        // HTML - Organization WEBSITE
        // HTML - Organization DESCRIPTION
    }
}
